@@ -7,6 +7,8 @@
 pub(crate) mod definition;
 pub mod header;
 pub mod objects;
+pub mod primitive_shapes;
 pub mod render;
 pub mod utils;
 pub mod window;
+pub use crate::header::*;
